/************** CHALLENGE:  Buttons ******************/
/**************    30 May 2018     ******************/
/***************************************************/

#include <msp430.h>


#include "peripherals.h"

#define BUTTON_S1 0x01
#define BUTTON_S2 0x02

#define LED_LEFT 0x02
#define LED_RIGHT  0x01
#define LED_NONE 0x00

// Function Prototypes
void swDelay(char numLoops);


// Declare globals here

// Main
void main(void)
{
	char button_state;
	unsigned int count = 0;

	WDTCTL = WDTPW | WDTHOLD;		// Stop watchdog timer


    // Useful code starts here
    initLaunchpadButtons();
    initLaunchpadLeds();

    while (1)    // Forever loop
  	{
    	button_state = readLaunchpadButtons();

    	// Increment counter when S2 (right button on Launchpad board) is pressed
    	if(button_state & BUTTON_S1) {
    	    count++;
    	}

    	// Clear counter when S1 (left button on Launchpad board) is pressed
    	if(button_state & BUTTON_S2) {
    		count = 0;
    		setLaunchpadLeds(LED_NONE);
    	}

    	// Turn on LED after S2 has been pressed 4 times
    	if(count == 4) {
    		setLaunchpadLeds(LED_RIGHT);
    	}

  	}  // end while (1)

}

void swDelay(char numLoops)
{
	// This function is a software delay. It performs
	// useless loops to waste a bit of time
	//
	// Input: numLoops = number of delay loops to execute
	// Output: none
	//
	// smj, ECE2049, 25 Aug 2013

	volatile unsigned int i,j;	// volatile to prevent optimization
			                            // by compiler

	for (j=0; j<numLoops; j++)
    {
    	i = 50000 ;					// SW Delay
   	    while (i > 0)				// could also have used while (i)
	       i--;
    }
}
